function v=compute_ekman_surge_eexp(vmax,rmax,r35,vt,phi,phi_in,w,a,n,lat)
% Computes ekman_surge_eexp
% Script automatically generated by fit_ekman_surge_eexp.m
% Inputs : 
% vmax           = Vmax (km/h)
% rmax           = Rmax (km)
% r35            = R35 (km)
% vt             = forward speed (km/h)
% phi            = track angle (deg)
% phi_in         = inflow angle (deg)
% w              = shelf width (km)
% a              = Dean slope a (-)
% n              = Mannings n
% lat            = latitude (deg)

% R2    = 0.7017
% RMSE  = 0.16581
% MEAN  = -0.1391
% RANGE = -0.68948 - 0.42349

beta( 1 )= -3.5835e-01 ;
beta( 2 )= 1.0236e+00 ;
beta( 3 )= 1.3703e+02 ;
beta( 4 )= -6.4623e+00 ;
beta( 5 )= 1.1261e-02 ;
beta( 6 )= -1.2360e-02 ;
beta( 7 )= 5.6489e-04 ;
beta( 8 )= 8.3620e-03 ;
beta( 9 )= 1.6022e-01 ;
beta( 10 )= -1.6729e-01 ;

v=beta(1) + beta(2)*exp(-w/beta(3)) + beta(4)*a + beta(5)*vt + beta(6)*lat + beta(7)*r35 + beta(8)*phi_in + beta(9).*sin(phi*pi/180) + beta(10).*cos(phi*pi/180);
